/* Logic_III_101.c
 *  
 * 
 * Device check default values:
 * avrdude -p m328p -c avrisp2                   						; command
 * avrdude: Device signature = 0x1e950f   (probably m328p)	; default values for m328p
 * avrdude: safemode: Fuses OK (E:FF, H:D9, L:62) 					; default values for m328p
 * 
 * 
 Fuse settings for 8MHz internal clock:
 * avrdude -p m328p -c avrisp2 -U lfuse:w:0xe2:m 
 * avrdude -p m328p -c avrisp2 -U hfuse:w:0xd9:m 
 * 
 * 
 * 
 * compile and flash:
 * - avr-gcc -Wall -Os -mmcu=atmega328p Logic_III_101.c -o Logic_III_101.elf
 * - avr-objcopy -O ihex -j .text -j .data Logic_III_101.elf Logic_III_101.hex
 * - avrdude -p m328p -c avrisp2 -U flash:w:Logic_III_101.hex
 * 
 * 
 * Hardware: m328p at 8Mhz internal
 * Board Logic_III_130_A / 2024_12 and 101_B / 2024_10
 * 							 
 * 
 * ================================================================================
 * 
 * Ports used:
 * 
 * input
 * PC0 Logic in A
 * PC1 Logic in B
 * 
 * output
 * PD0 0001
 * PD1 0010
 * PD2 0011
 * PD3 0100
 * PD4 0101 
 * PD5 0110
 * PD6 0111
 * PD7 1000
 *
 * PB0 1001
 * PB1 1010
 * PB2 1011
 * PB3 1100
 * PB4 1101
 * PB5 1110
 * 
 * =========================================================================================
 * 
 * Description:
 * 
 * 20250328
 * Start; First run; working;
 * 
 * 
*/

#include <avr/io.h>
#include <stdbool.h>


void init_ports(void)
{
	// input
	DDRC &=~ (1 << PC0);							// set PC0 as input A;
	DDRC &=~ (1 << PC1);							// set PC1 as input B;
	
	// output
	DDRD |= (1<<PD0);									// Output 0001
	DDRD |= (1<<PD1);									// Output 0010
	DDRD |= (1<<PD2);									// Output 0011
	DDRD |= (1<<PD3);									// Output 0100
	DDRD |= (1<<PD4);									// Output 0101
	DDRD |= (1<<PD5);									// Output 0110
	DDRD |= (1<<PD6);									// Output 0111
	DDRD |= (1<<PD7);									// Output 1000
	DDRB |= (1<<PB0);									// Output 1001
	DDRB |= (1<<PB1);									// Output 1010
	DDRB |= (1<<PB2);									// Output 1011
	DDRB |= (1<<PB3);									// Output 1100
	DDRB |= (1<<PB4);									// Output 1101
	DDRB |= (1<<PB5);									// Output 1110
}



	
int main(void)
	{
		bool input_A = false;								// Holds input A state
		bool input_B = false;								// Holds input B state 
		
		init_ports();
		PORTD = 0b00000000;							// All outputs off
		PORTB = 0b00000000;							// All outputs off
		
		while(1)
		{        		
			input_A = (PINC & (1 << PC0));									// Read input A state every loop
			input_B = (PINC & (1 << PC1));									// Read input B state every loop
				if ((input_A == false) && (input_B == false))	// input 00
				{
				 PORTD = 0b01010101;
				 PORTB = 0b00010101;
				}
				if ((input_A == false) && (input_B == true))	// input 01
				{
				 PORTD = 0b01100110;
				 PORTB = 0b00100110;
				}
				if ((input_A == true) && (input_B == false))	// input 10
				{
				 PORTD = 0b01111000;
				 PORTB = 0b00111000;
				}
				if ((input_A == true) && (input_B == true))		// input 11
				{
				 PORTD = 0b10000000;
				 PORTB = 0b00111111;
				}
		}  
		return(0);																		// You'll never reach this line
	}
